@@ -12,9 +12,10 @@ from releasemanager.persist import Persistence
 
 class ReleaseManager(object):
     """the brains of the operation ;) """
-    def __init__(self, configName, configPath=None):
+    def __init__(self, configName, configPath=None, configStyle='py'):
         self._configPath = configPath
         self._configName = configName
+        self._configStyle = configStyle
         self.load()
 
 
@@ -26,7 +27,7 @@ class ReleaseManager(object):
 
 
     def _loadConfig(self):
-        self._config = ConfigLoader(self._configPath).load(self._configName)
+        self._config = ConfigLoader(self._configPath, self._configStyle).load(self._configName)
         self.logger = ReleaseLogger(self._config, configPath=self._configPath)
     
     def _buildPersistence(self):
